rnalysis.feature\_name\_to\_wbgene.GeneNameTranslator.\_\_init\_\_
==================================================================

.. currentmodule:: rnalysis.feature_name_to_wbgene

.. automethod:: GeneNameTranslator.__init__